==> react-hr-component-kc-1.0.42.tgz: package/src/components/UpdateEntityDeploymentInfoTest.js <==
import React, { useState, useEffect } from "react";
import ReactDOM from "react-dom";
//import Button from "@material-ui/core/Button";
import { useLocation } from "react-router-dom";
import { Form, Row, Col, Button } from "react-bootstrap";
import axios from "axios";

function UpdateEntityDeploymentInfoTest(props) {
  const location = useLocation();
  const [entityDeploymentData, setEntityDeploymentData] = useState({
    entityName: "",
    entityType: "",
    entityBranchMappings: [
      {
        entityPatternName: "",
        entityDeploymentInfo: [
          {
            entityOrg: "",
            entityEnvironment: "",
            entityHost: "",
          },
        ],
      },
    ],
  });

  useEffect(() => {
    console.log("url1", new URLSearchParams(
      location.search
    ));
    console.log("url2", location.search);
  },[])

  //load existing entity details
  useEffect(() => {
    axios
      .get("https://configurator-api-m7mkmev5sq-uc.a.run.app/assets/sample")
      .then((response) => {
        setEntityDeploymentData({
          entityName: response.data.name,
          entityType: response.data.type,
          entityBranchMappings: response.data.branchMappings.map((bm, ix) => ({
            entityPatternName: bm.branchPattern,
            entityDeploymentInfo: bm.deploymentInfo.map((eid, idx) => ({
              entityOrg: eid.org,
              entityEnvironment: eid.env,
              entityHost: eid.host,
            })),
          })),
        });
      });
  }, []);

  //add pattern
  const addPattern = (e) => {
    let temp = { ...entityDeploymentData };
    temp.entityBranchMappings.push({
      entityPatternName: "",
      entityDeploymentInfo: [
        {
          entityOrg: "",
          entityEnvironment: "",
          entityHost: "",
        },
      ],
    });
    setEntityDeploymentData(temp);
  };

  //add org
  const addOrg = (e, i) => {
    let temp = { ...entityDeploymentData };
    temp.entityBranchMappings[i].entityDeploymentInfo.push({
      entityOrg: "",
      entityEnvironment: "",
      entityHost: "",
    });
    setEntityDeploymentData(temp);
  };

  //remove pattern
  const deletePattern = (e, i) => {
    let temp = { ...entityDeploymentData };
    temp.entityBranchMappings.splice(i, 1);
    setEntityDeploymentData(temp);
  };

  //remove org
  const deleteOrg = (e, i, j) => {
    let temp = { ...entityDeploymentData };
    temp.entityBranchMappings[i].entityDeploymentInfo.splice(j, 1);
    setEntityDeploymentData(temp);
  };

  //entity name change
  // const handleEntityNameChange = (e) => {
  //   let temp = { ...entityDeploymentData };
  //   temp[e.target.name] = e.target.value;
  //   setEntityDeploymentData(temp);
  // };

  //entity type change
  // const handleEntityTypeChange = (e) => {
  //   let temp = { ...entityDeploymentData };
  //   temp[e.target.name] = e.target.value;
  //   setEntityDeploymentData(temp);
  // };

  //pattern name change
  const handlePatternNameChange = (e, i) => {
    let temp = { ...entityDeploymentData };
    temp.entityBranchMappings[i][e.target.name] = e.target.value;
    setEntityDeploymentData(temp);
  };

  //org name change
  const handleEntityOrgChange = (e, i, j) => {
    let temp = { ...entityDeploymentData };
    temp.entityBranchMappings[i].entityDeploymentInfo[j].entityOrg =
      e.target.value;
    setEntityDeploymentData(temp);
  };

  //environment name change
  const handleEntityEnvironmentChange = (e, i, j) => {
    let temp = { ...entityDeploymentData };
    temp.entityBranchMappings[i].entityDeploymentInfo[j].entityEnvironment =
      e.target.value;
    setEntityDeploymentData(temp);
  };

  //vhost name change
  const handleEntityHostChange = (e, i, j) => {
    let temp = { ...entityDeploymentData };
    temp.entityBranchMappings[i].entityDeploymentInfo[j].entityHost =
      e.target.value;
    setEntityDeploymentData(temp);
  };

  const submit = (e) => {
    console.log(entityDeploymentData);
  };

  return (
    <section>
      <div className="developer-list-page">
        <div className="container">
          <div className="col-sm-12">
            <h2>Onboard Org & Env</h2>
            <ul className="breadcrumb">
              <li className="breadcrumb-item">
                <a href="/">Home</a>
              </li>
              <li className="breadcrumb-item active">
                <a href="/onboard-entity-deployment-info">
                  Update Entity Deployment Info
                </a>
              </li>
            </ul>
          </div>
        </div>
      </div>
      <main id="main mt-5">
        <section id="subpage" className="wow fadeInUp">
          <div className="upload-swagger">
            <div className="container">
              <div className="row form-section nopadding">
                <div className="col-lg-3">{props.leftNavigation}</div>
                <div className="col-lg-9 col-sm-12 swag-border-left">
                  <div className="pageHeaders">
                    <div className="mb-3">
                      <Form>
                        <Form.Group as={Row} controlId="entityName">
                          <Form.Label column sm={2}>
                            Entity Name <span className="required">*</span>
                          </Form.Label>
                          <Col sm={10}>
                            <Form.Control
                              className="w-75"
                              name="entityName"
                              plaintext
                              readOnly
                              // onChange={handleEntityNameChange}
                              //value={entityDeploymentData.entityName}
                              defaultValue={entityDeploymentData.entityName}
                            />
                          </Col>
                        </Form.Group>
                        <Form.Group as={Row} controlId="entityType">
                          <Form.Label column sm={2}>
                            Entity Type <span className="required">*</span>
                          </Form.Label>
                          <Col sm={10}>
                            <Form.Control
                              className="w-75"
                              name="entityType"
                              plaintext
                              readOnly
                              // onChange={handleEntityTypeChange}
                              // value={entityDeploymentData.entityType}
                              defaultValue={entityDeploymentData.entityType}
                            />
                          </Col>
                        </Form.Group>
                        <p>Add/Update pattern information:</p>
                        {entityDeploymentData.entityBranchMappings.map(
                          (branch, i) => (
                            <div className="group-field-highlight-pattern-info ">
                              <Form.Group
                                as={Row}
                                controlId="entityPatternName"
                              >
                                <Form.Label column sm={2}>
                                  Pattern Name{" "}
                                  <span className="required">*</span>
                                </Form.Label>
                                <Col sm={10}>
                                  <Form.Control
                                    type="text"
                                    className="w-75"
                                    name="entityPatternName"
                                    onChange={(e) =>
                                      handlePatternNameChange(e, i)
                                    }
                                    value={
                                      entityDeploymentData.entityBranchMappings[
                                        i
                                      ].entityPatternName
                                    }
                                  />
                                </Col>
                              </Form.Group>

                              <Button
                                variant="secondary"
                                onClick={(e) => deletePattern(e, i)}
                              >
                                -Pattern
                              </Button>
                              {branch.entityDeploymentInfo.map((host, j) => (
                                <div className="group-field-highlight-org-info">
                                  <Form.Group as={Row} controlId="entityOrg">
                                    <Form.Label column sm={2}>
                                      Org <span className="required">*</span>
                                    </Form.Label>
                                    <Col sm={10}>
                                      <div className="row org-button">
                                        <Form.Control
                                          type="text"
                                          className="w-75"
                                          name="entityOrg"
                                          onChange={(e) =>
                                            handleEntityOrgChange(e, i, j)
                                          }
                                          value={
                                            entityDeploymentData
                                              .entityBranchMappings[i]
                                              .entityDeploymentInfo[j].entityOrg
                                          }
                                        />
                                        <Button
                                          variant="secondary"
                                          onClick={(e) => deleteOrg(e, i, j)}
                                        >
                                          -Org
                                        </Button>
                                      </div>
                                    </Col>
                                  </Form.Group>
                                  <Form.Group
                                    as={Row}
                                    controlId="entityEnvironment"
                                  >
                                    <Form.Label column sm={2}>
                                      Env <span className="required">*</span>
                                    </Form.Label>
                                    <Col sm={10}>
                                      <Form.Control
                                        type="text"
                                        className="w-75"
                                        name="entityEnvironment"
                                        onChange={(e) =>
                                          handleEntityEnvironmentChange(e, i, j)
                                        }
                                        value={
                                          entityDeploymentData
                                            .entityBranchMappings[i]
                                            .entityDeploymentInfo[j]
                                            .entityEnvironment
                                        }
                                      />
                                    </Col>
                                  </Form.Group>
                                  <Form.Group as={Row} controlId="entityHost">
                                    <Form.Label column sm={2}>
                                      Host <span className="required">*</span>
                                    </Form.Label>
                                    <Col sm={10}>
                                      <Form.Control
                                        type="text"
                                        className="w-75"
                                        name="entityHost"
                                        onChange={(e) =>
                                          handleEntityHostChange(e, i, j)
                                        }
                                        value={
                                          entityDeploymentData
                                            .entityBranchMappings[i]
                                            .entityDeploymentInfo[j].entityHost
                                        }
                                      />
                                    </Col>
                                  </Form.Group>
                                </div>
                              ))}
                              <Button
                                variant="primary"
                                onClick={(e) => addOrg(e, i)}
                              >
                                +Org
                              </Button>
                            </div>
                          )
                        )}
                      </Form>
                      <Button variant="primary" onClick={addPattern}>
                        +Pattern
                      </Button>{" "}
                      <br />
                      <br />
                      <Button variant="primary" onClick={submit}>
                        Submit
                      </Button>
                    </div>
                  </div>
                </div>
              </div>
            </div>
          </div>
        </section>
      </main>
    </section>
  );
}

export default UpdateEntityDeploymentInfoTest;

==> react-hr-component-kc-1.0.45.tgz: package/src/components/UpdateEntityDeploymentInfoTest.js <==
import React, { useState, useEffect } from "react";
import ReactDOM from "react-dom";
//import Button from "@material-ui/core/Button";
import { useLocation } from "react-router-dom";
import { Form, Row, Col, Button } from "react-bootstrap";
import axios from "axios";

function UpdateEntityDeploymentInfoTest(props) {
  const location = useLocation();
  const [entityDeploymentData, setEntityDeploymentData] = useState({
    entityName: "",
    entityType: "",
    entityBranchMappings: [
      {
        entityPatternName: "",
        entityDeploymentInfo: [
          {
            entityOrg: "",
            entityEnvironment: "",
            entityHost: "",
          },
        ],
      },
    ],
  });

  useEffect(() => {
    console.log("p1", new URLSearchParams(
      location.search
    ).get("entity_name"));
    console.log("p2", new URLSearchParams(
      location.search
    ).get("param2"));
    console.log("p3", new URLSearchParams(
      location.search
    ).get("param3"));
  },[])

  //load existing entity details
  useEffect(() => {
    axios
      .get("https://configurator-api-m7mkmev5sq-uc.a.run.app/assets/sample")
      .then((response) => {
        setEntityDeploymentData({
          entityName: response.data.name,
          entityType: response.data.type,
          entityBranchMappings: response.data.branchMappings.map((bm, ix) => ({
            entityPatternName: bm.branchPattern,
            entityDeploymentInfo: bm.deploymentInfo.map((eid, idx) => ({
              entityOrg: eid.org,
              entityEnvironment: eid.env,
              entityHost: eid.host,
            })),
          })),
        });
      });
  }, []);

  //add pattern
  const addPattern = (e) => {
    let temp = { ...entityDeploymentData };
    temp.entityBranchMappings.push({
      entityPatternName: "",
      entityDeploymentInfo: [
        {
          entityOrg: "",
          entityEnvironment: "",
          entityHost: "",
        },
      ],
    });
    setEntityDeploymentData(temp);
  };

  //add org
  const addOrg = (e, i) => {
    let temp = { ...entityDeploymentData };
    temp.entityBranchMappings[i].entityDeploymentInfo.push({
      entityOrg: "",
      entityEnvironment: "",
      entityHost: "",
    });
    setEntityDeploymentData(temp);
  };

  //remove pattern
  const deletePattern = (e, i) => {
    let temp = { ...entityDeploymentData };
    temp.entityBranchMappings.splice(i, 1);
    setEntityDeploymentData(temp);
  };

  //remove org
  const deleteOrg = (e, i, j) => {
    let temp = { ...entityDeploymentData };
    temp.entityBranchMappings[i].entityDeploymentInfo.splice(j, 1);
    setEntityDeploymentData(temp);
  };

  //entity name change
  // const handleEntityNameChange = (e) => {
  //   let temp = { ...entityDeploymentData };
  //   temp[e.target.name] = e.target.value;
  //   setEntityDeploymentData(temp);
  // };

  //entity type change
  // const handleEntityTypeChange = (e) => {
  //   let temp = { ...entityDeploymentData };
  //   temp[e.target.name] = e.target.value;
  //   setEntityDeploymentData(temp);
  // };

  //pattern name change
  const handlePatternNameChange = (e, i) => {
    let temp = { ...entityDeploymentData };
    temp.entityBranchMappings[i][e.target.name] = e.target.value;
    setEntityDeploymentData(temp);
  };

  //org name change
  const handleEntityOrgChange = (e, i, j) => {
    let temp = { ...entityDeploymentData };
    temp.entityBranchMappings[i].entityDeploymentInfo[j].entityOrg =
      e.target.value;
    setEntityDeploymentData(temp);
  };

  //environment name change
  const handleEntityEnvironmentChange = (e, i, j) => {
    let temp = { ...entityDeploymentData };
    temp.entityBranchMappings[i].entityDeploymentInfo[j].entityEnvironment =
      e.target.value;
    setEntityDeploymentData(temp);
  };

  //vhost name change
  const handleEntityHostChange = (e, i, j) => {
    let temp = { ...entityDeploymentData };
    temp.entityBranchMappings[i].entityDeploymentInfo[j].entityHost =
      e.target.value;
    setEntityDeploymentData(temp);
  };

  const submit = (e) => {
    console.log(entityDeploymentData);
  };

  return (
    <section>
      <div className="developer-list-page">
        <div className="container">
          <div className="col-sm-12">
            <h2>Onboard Org & Env</h2>
            <ul className="breadcrumb">
              <li className="breadcrumb-item">
                <a href="/">Home</a>
              </li>
              <li className="breadcrumb-item active">
                <a href="/onboard-entity-deployment-info">
                  Update Entity Deployment Info
                </a>
              </li>
            </ul>
          </div>
        </div>
      </div>
      <main id="main mt-5">
        <section id="subpage" className="wow fadeInUp">
          <div className="upload-swagger">
            <div className="container">
              <div className="row form-section nopadding">
                <div className="col-lg-3">{props.leftNavigation}</div>
                <div className="col-lg-9 col-sm-12 swag-border-left">
                  <div className="pageHeaders">
                    <div className="mb-3">
                      <Form>
                        <Form.Group as={Row} controlId="entityName">
                          <Form.Label column sm={2}>
                            Entity Name <span className="required">*</span>
                          </Form.Label>
                          <Col sm={10}>
                            <Form.Control
                              className="w-75"
                              name="entityName"
                              plaintext
                              readOnly
                              // onChange={handleEntityNameChange}
                              //value={entityDeploymentData.entityName}
                              defaultValue={entityDeploymentData.entityName}
                            />
                          </Col>
                        </Form.Group>
                        <Form.Group as={Row} controlId="entityType">
                          <Form.Label column sm={2}>
                            Entity Type <span className="required">*</span>
                          </Form.Label>
                          <Col sm={10}>
                            <Form.Control
                              className="w-75"
                              name="entityType"
                              plaintext
                              readOnly
                              // onChange={handleEntityTypeChange}
                              // value={entityDeploymentData.entityType}
                              defaultValue={entityDeploymentData.entityType}
                            />
                          </Col>
                        </Form.Group>
                        <p>Add/Update pattern information:</p>
                        {entityDeploymentData.entityBranchMappings.map(
                          (branch, i) => (
                            <div className="group-field-highlight-pattern-info ">
                              <Form.Group
                                as={Row}
                                controlId="entityPatternName"
                              >
                                <Form.Label column sm={2}>
                                  Pattern Name{" "}
                                  <span className="required">*</span>
                                </Form.Label>
                                <Col sm={10}>
                                  <Form.Control
                                    type="text"
                                    className="w-75"
                                    name="entityPatternName"
                                    onChange={(e) =>
                                      handlePatternNameChange(e, i)
                                    }
                                    value={
                                      entityDeploymentData.entityBranchMappings[
                                        i
                                      ].entityPatternName
                                    }
                                  />
                                </Col>
                              </Form.Group>

                              <Button
                                variant="secondary"
                                onClick={(e) => deletePattern(e, i)}
                              >
                                -Pattern
                              </Button>
                              {branch.entityDeploymentInfo.map((host, j) => (
                                <div className="group-field-highlight-org-info">
                                  <Form.Group as={Row} controlId="entityOrg">
                                    <Form.Label column sm={2}>
                                      Org <span className="required">*</span>
                                    </Form.Label>
                                    <Col sm={10}>
                                      <div className="row org-button">
                                        <Form.Control
                                          type="text"
                                          className="w-75"
                                          name="entityOrg"
                                          onChange={(e) =>
                                            handleEntityOrgChange(e, i, j)
                                          }
                                          value={
                                            entityDeploymentData
                                              .entityBranchMappings[i]
                                              .entityDeploymentInfo[j].entityOrg
                                          }
                                        />
                                        <Button
                                          variant="secondary"
                                          onClick={(e) => deleteOrg(e, i, j)}
                                        >
                                          -Org
                                        </Button>
                                      </div>
                                    </Col>
                                  </Form.Group>
                                  <Form.Group
                                    as={Row}
                                    controlId="entityEnvironment"
                                  >
                                    <Form.Label column sm={2}>
                                      Env <span className="required">*</span>
                                    </Form.Label>
                                    <Col sm={10}>
                                      <Form.Control
                                        type="text"
                                        className="w-75"
                                        name="entityEnvironment"
                                        onChange={(e) =>
                                          handleEntityEnvironmentChange(e, i, j)
                                        }
                                        value={
                                          entityDeploymentData
                                            .entityBranchMappings[i]
                                            .entityDeploymentInfo[j]
                                            .entityEnvironment
                                        }
                                      />
                                    </Col>
                                  </Form.Group>
                                  <Form.Group as={Row} controlId="entityHost">
                                    <Form.Label column sm={2}>
                                      Host <span className="required">*</span>
                                    </Form.Label>
                                    <Col sm={10}>
                                      <Form.Control
                                        type="text"
                                        className="w-75"
                                        name="entityHost"
                                        onChange={(e) =>
                                          handleEntityHostChange(e, i, j)
                                        }
                                        value={
                                          entityDeploymentData
                                            .entityBranchMappings[i]
                                            .entityDeploymentInfo[j].entityHost
                                        }
                                      />
                                    </Col>
                                  </Form.Group>
                                </div>
                              ))}
                              <Button
                                variant="primary"
                                onClick={(e) => addOrg(e, i)}
                              >
                                +Org
                              </Button>
                            </div>
                          )
                        )}
                      </Form>
                      <Button variant="primary" onClick={addPattern}>
                        +Pattern
                      </Button>{" "}
                      <br />
                      <br />
                      <Button variant="primary" onClick={submit}>
                        Submit
                      </Button>
                    </div>
                  </div>
                </div>
              </div>
            </div>
          </div>
        </section>
      </main>
    </section>
  );
}

export default UpdateEntityDeploymentInfoTest;
